function [dlist,dnum,index] = rfx_get_description(imgs,opts)
%
% compiles a unique list of image descriptions and count the
% number of occurrences
% -------------------------------------------------------------------------
% $Id: rfx_get_description.m 3 2008-12-10 06:18:11Z glaescher $

global des;

nSub = length(imgs);
desc = {};

switch opts.prefix
  
  case 'beta'
    for s = 1:nSub
      for i = 1:length(imgs(s).beta)
        ix = strfind(imgs(s).beta(i).descrip,' - ');
        desc{end+1} = imgs(s).beta(i).descrip(ix+3:end);
      end
    end
  case {'con','ess','spmT','spmF'}
    for s=1:nSub
      for i = 1:length(imgs(s).xcon)
        if strcmp(imgs(s).xcon(i).STAT,'T')
          %ix = strfind(imgs(s).xcon(i).Vcon.descrip,': ');
          %desc{end+1} = imgs(s).xcon(i).Vcon.descrip(ix+2:end);
          desc{end+1} = imgs(s).xcon(i).name;
        end
      end
    end
  otherwise
    for s = 1:nSub
      for i = 1:length(imgs(s).myimgs)
        desc{end+1} = imgs(s).myimgs(i).descrip;
      end
    end
    
end

[dlist,dnum] = rfx_unique_unsorted(desc);

% create an index matrix that maps each unique description back onto
% individual FFX regressor numbers ...

len = length(dlist);

index = struct('n', ones(nSub,len)*NaN, ...
  's', zeros(nSub,len), ...
  'u', zeros(nSub,len), ...
  'p', zeros(nSub,len), ...
  'b', zeros(nSub,len), ...
  'h', zeros(nSub,len));

switch opts.prefix
  case 'beta'
     for s = 1:nSub
        
        for d = 1:length(dlist)

          for b = 1:length(imgs(s).beta)
            if strfind(imgs(s).beta(b).descrip,dlist{d})
              % we found the regressor in the beta descriptions
              index.s(s,d) = str2double(dlist{d}(4)); % session
              index.n(s,d) = b;                   % regressor
              core = '';
              
              bb = strfind(dlist{d},'*bf(');      % basis function?
              if ~isempty(bb)
                index.b(s,d) = str2double(dlist{d}(bb+4));
                core = dlist{d}(7:bb-1);          % core name
              end
              
              p = strfind(dlist{d},'^');          % pmod?
              if ~isempty(p)
                index.h(s,d) = str2double(dlist{d}(p+1));
                core = dlist{d}(7:p-1);           % core name
              end

              if isempty(core)
                core = dlist{d}(7:end);           % core name (failback)
              end
              
              ses  = index.s(s,d);
              U = des(s).Sess(ses).U;
              for u = 1:length(U)
                % setup and internal numbering of pmods within the reg
                p = 0;
                if ~isempty(U(u).P(1).P)
                  for pp = 1:length(U(u).P)
                    p = [p repmat(pp,1,U(u).P(pp).h)];
                  end
                end
                
                for n = 1:length(U(u).name)
                  if ~isempty(strfind(U(u).name{n},core))
                    index.u(s,d) = u;
                    index.p(s,d) = p(n);
                    break;
                  end
                end
              end
            end
          end
        end
      end
  case {'con','ess','spmT','spmF'}
    for s = 1:nSub
      for d = 1:length(dlist)
        index.n(s,d) = NaN;
        ind = strmatch(dlist{d},cellstr(strvcat(imgs(s).xcon(:).name)),'exact');
        if ~isempty(ind)
          index.n(s,d) = ind;
        end
      end
    end
end

return;
