function imgs = rfx_get_vol_img(dirs,opts)
%
% loads or compiles a struct array of SPM images (beta,con,spmT,
% spmF,mask,ResMS) and places it into global workspace
% -------------------------------------------------------------------------
% $Id: rfx_get_vol_img.m 3 2008-12-10 06:18:11Z glaescher $

global imgs rfximgs defs;

nSub = length(dirs);

if ~strcmp(rfximgs,opts.rfxdir)
	imgs = [];
end

if isempty(imgs)
  try
    fprintf('Loading image handles from rfx_images.mat ... ')
    tic;
    load(fullfile(opts.rfxdir,'rfx_images.mat'));
    tim = toc;
    if tim > 60
      fprintf('done (%1.2f min).\n',tim/60);
    else
      fprintf('done (%1.1f sec).\n',tim);
    end
  catch
    fprintf('failed. (Don''t worry.)\n');
    fprintf('Creating rfx_images.mat ...\n');
    imgs = struct;
    tic;
    for s = 1:nSub
      fprintf('%-40s',sprintf('Compiling image handles for subject %02d',s));
      load(fullfile(dirs{s},'SPM.mat'));
      pth = SPM.swd;
      imgs(s).beta  = SPM.Vbeta;
      imgs(s).xcon  = SPM.xCon;
      imgs(s).resms = SPM.VResMS;
      for i = 1:length(imgs(s).beta)
        if isempty(strfind(imgs(s).beta(i).fname,filesep))
          imgs(s).beta(i).fname = fullfile(pth,imgs(s).beta(i).fname);
        end
      end
      for i = 1:length(imgs(s).xcon)
        if isempty(imgs(s).xcon(i).Vcon) || isempty(imgs(s).xcon(i).Vspm)
          disp(sprintf('I could not find an valid image handle for contrast "%s"',...
            imgs(s).xcon(i).name));
          disp('Please download the function "revol_xcon.m" from the Support section');
          disp('at http://rfxplot.sourceforge.net and do the following:');
          disp('1. change directory to your 2nd level analysis');
          disp('2. type: load SPM.mat');
          disp('3. type: dirs = rfx_get_dirs(SPM);');
          disp('4. type: revol_xcon(dirs);');
          disp('5. type: delete(''rfx*.mat'')');
          disp('6. type: close all; clear all');
          disp('7. Restart SPM, select 2nd level analysis, and restart rfxplot')
          disp('If you still get the same error message, please file a bug report')
          disp('at http://rfxplot.sourceforge.net. Thanks.')
          return;
        end
        if isempty(strfind(imgs(s).xcon(i).Vcon.fname,filesep))
          imgs(s).xcon(i).Vcon.fname = fullfile(pth,imgs(s).xcon(i).Vcon.fname);
          imgs(s).xcon(i).Vspm.fname = fullfile(pth,imgs(s).xcon(i).Vspm.fname);
        end
      end
      imgs(s).resms.fname = fullfile(pth,imgs(s).resms.fname);
      std_prefix = {'beta','con','ess','spmT','spmF','ResMS'};
      if isempty(strmatch(opts.prefix,std_prefix))
        for s=1:nSub
          myimgs = rfx_lselect(dirs{s},sprintf('^%s.*\\.img',opts.prefix));
          imgs(s).myimg = spm_vol(myimgs);
        end
      end
      fprintf('%s',repmat(sprintf('\b'),1,40));
    end
    tim = toc;
    if tim > 60
      fprintf('Completed in %1.2f min.\n',tim/60);
    else
      fprintf('Completed in %1.1f sec.\n',tim);
    end    
    if defs.savemat.images
      fprintf('\nSaving image handles to rfx_images.mat ... ');
      tic;
      save(fullfile(opts.rfxdir,'rfx_images.mat'),'imgs');
      tim = toc;
      if tim > 60
        fprintf('done (%1.2f min).\n',tim/60);
      else
        fprintf('done (%1.1f sec).\n',tim);
      end
    else
      fprintf('\nAbort saving image handles at user request.\n')
    end
  end

end

rfximgs = opts.rfxdir;
return;
